@@ -69,7 +69,8 @@ io_csv.character <- function(
 #' @param x data.frame
 #' @param file passed to \code{\link[csv]{as.csv.data.frame}} (by method dispatch)
 #' @param ext = extension for metadata equivalent of x
-#' @param coerce logical; whether to coerce factor levels to guide; alternatively, a key for the levels
+# coerce was passed to io_yamlet, which does not implement it
+# @param coerce logical; whether to coerce factor levels to guide; alternatively, a key for the levels
 #' @param con passed to \code{\link{io_yamlet}}
 #' @param useBytes passed to \code{\link{io_yamlet}}
 #' @param default_keys passed to \code{\link{io_yamlet}}
@@ -86,7 +87,7 @@ io_csv.data.frame <- function(
   x,
   file = '',
   ext = getOption('yamlet_extension', '.yaml'),
-  coerce = getOption("yamlet_coerce_decorations", FALSE),
+  # coerce = getOption("yamlet_coerce_decorations", FALSE),
   con = stdout(),
   useBytes = FALSE,
   default_keys = getOption(
@@ -107,7 +108,7 @@ io_csv.data.frame <- function(
     con = con,
     useBytes = useBytes,
     default_keys = default_keys,
-    coerce = coerce,
+    # coerce = coerce,
     ...
   )
   invisible(file)
